@@ -58,7 +58,7 @@ describe("threats", function()
 		StartDoctypeDecl = { "parser", "name", "sysid", "pubid", "has_internal_subset" },
 		StartElement = { "parser", "elementName", "attributes" },
 		StartNamespaceDecl = { "parser", "namespaceName", "namespaceUri" },
-		--UnparsedEntityDecl = { "parser", "entityName", "base", "systemId", "publicId", "notationName" },  -- superseeded by EntityDecl
+		--UnparsedEntityDecl = { "parser", "entityName", "base", "systemId", "publicId", "notationName" },  -- superseded by EntityDecl
 		XmlDecl = { "parser", "version", "encoding", "standalone" },
 	}
 
@@ -1228,6 +1228,21 @@ describe("threats", function()
 			assert.falsy(r)
 		end)
 
+
+		it("accepts empty URI", function()
+			local doc = [[<root xmlns="">txt</root>]]
+			local r, err = p:parse(doc)
+			assert.equal(nil, err)
+			assert.truthy(r)
+			assert.same({
+				{ "StartNamespaceDecl" },
+				{ "StartElement", "root", {} },
+				{ "CharacterData", "txt" },
+				{ "EndElement", "root" },
+				{ "EndNamespaceDecl" }
+			}, cbdata)
+		end)
+
 	end)
 
 
